===============================
Ambient Radio Weather Network
===============================

.. image:: https://img.shields.io/pypi/v/arwn.svg
        :target: https://pypi.python.org/pypi/arwn

.. image:: https://img.shields.io/travis/sdague/arwn.svg
        :target: https://travis-ci.org/sdague/arwn

.. image:: https://readthedocs.org/projects/arwn/badge/?version=latest
        :target: https://readthedocs.org/projects/arwn/?badge=latest
        :alt: Documentation Status


Collect 433Mhz weather sensor data and publish to mqtt

* Free software: ISC license
* Documentation: https://arwn.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
